==> ugene_1.19.0%2Bdfsg.orig.tar.xz: ugene-1.19.0/src/plugins_3rdparty/kalign/transl/english.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US" sourcelanguage="en">
<context>
    <name>KalignDialog</name>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="32"/>
        <source>Align with Kalign</source>
        <translation>Align with Kalign</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="54"/>
        <source>Input file</source>
        <translation>Input file</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="64"/>
        <location filename="../src/ui/KalignDialog.ui" line="81"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="71"/>
        <location filename="../src/ui/KalignDialog.ui" line="307"/>
        <source>Output file</source>
        <translation>Output file</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="99"/>
        <source>Advanced options</source>
        <translation>Advanced options</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="114"/>
        <source>Gap open penalty</source>
        <translation>Gap open penalty</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="160"/>
        <source>Gap extension penalty</source>
        <translation>Gap extension penalty</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="206"/>
        <source>Terminal gap penalty</source>
        <translation>Terminal gap penalty</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="252"/>
        <source>Bonus score</source>
        <translation>Bonus score</translation>
    </message>
    <message>
        <location filename="../src/ui/KalignDialog.ui" line="295"/>
        <source>Translate to amino when aligning</source>
        <translation>Translate to amino when aligning</translation>
    </message>
</context>
<context>
    <name>PairwiseAlignmentHirschbergOptionsPanelMainWidget</name>
    <message>
        <location filename="../src/ui/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/ui/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="37"/>
        <source>Gap open penalty</source>
        <translation>Gap open penalty</translation>
    </message>
    <message>
        <location filename="../src/ui/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="57"/>
        <source>Gap extension penalty</source>
        <translation>Gap extension penalty</translation>
    </message>
    <message>
        <location filename="../src/ui/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="77"/>
        <source>Terminate gap penalty</source>
        <translation>Terminate gap penalty</translation>
    </message>
    <message>
        <location filename="../src/ui/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="97"/>
        <source>Bonus score</source>
        <translation>Bonus score</translation>
    </message>
</context>
<context>
    <name>U2::KalignAdapter</name>
    <message>
        <location filename="../src/KalignAdapter.cpp" line="54"/>
        <source>Internal Kalign error: %1</source>
        <translation>Internal Kalign error: %1</translation>
    </message>
</context>
<context>
    <name>U2::KalignAlignWithExtFileSpecifyDialogController</name>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="133"/>
        <source>Align</source>
        <translation>Align</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="134"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="150"/>
        <source>Open an alignment file</source>
        <translation>Open an alignment file</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="160"/>
        <source>Save an multiple alignment file</source>
        <translation>Save an multiple alignment file</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="200"/>
        <location filename="../src/KalignDialogController.cpp" line="203"/>
        <source>Kalign with Align</source>
        <translation>Align with Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="201"/>
        <source>Input file is not set!</source>
        <translation>Input file is not set!</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="204"/>
        <source>Output file is not set!</source>
        <translation>Output file is not set!</translation>
    </message>
</context>
<context>
    <name>U2::KalignDialogController</name>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="70"/>
        <source>Align</source>
        <translation>Align</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="71"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>U2::KalignGObjectRunFromSchemaTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="255"/>
        <source>Workflow wrapper &apos;%1&apos;</source>
        <translation>Workflow wrapper &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="265"/>
        <source>KAlign align &apos;%1&apos;</source>
        <translation>KAlign align &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::KalignGObjectTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="146"/>
        <source>KALIGN align &apos;%1&apos;</source>
        <translation>KALIGN align &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::KalignMSAEditorContext</name>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="154"/>
        <source>Align with Kalign...</source>
        <translation>Align with Kalign...</translation>
    </message>
</context>
<context>
    <name>U2::KalignPlugin</name>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="70"/>
        <source>Kalign</source>
        <translation>Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="71"/>
        <source>A port of Kalign package for multiple sequence alignment. Check http://msa.sbc.su.se for the original version</source>
        <translation>A port of Kalign package for multiple sequence alignment. Check http://msa.sbc.su.se for the original version</translation>
    </message>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="81"/>
        <source>Align with Kalign...</source>
        <translation>Align with Kalign...</translation>
    </message>
</context>
<context>
    <name>U2::KalignTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="73"/>
        <source>KALIGN alignment</source>
        <translation>KALIGN alignment</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="91"/>
        <source>Unsupported alphabet: %1</source>
        <translation>Unsupported alphabet: %1</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="94"/>
        <source>Kalign alignment started</source>
        <translation>Kalign alignment started</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="99"/>
        <source>Kalign alignment successfully finished</source>
        <translation>Kalign alignment successfully finished</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::KalignPrompter</name>
    <message>
        <location filename="../src/KalignWorker.cpp" line="122"/>
        <source> from %1</source>
        <translation> from %1</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="124"/>
        <source>Aligns each MSA supplied &lt;u&gt;%1&lt;/u&gt; with &quot;&lt;u&gt;Kalign&lt;/u&gt;&quot;.</source>
        <translation>Aligns each MSA supplied &lt;u&gt;%1&lt;/u&gt; with &quot;&lt;u&gt;Kalign&lt;/u&gt;&quot;.</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::KalignWorker</name>
    <message>
        <location filename="../src/KalignWorker.cpp" line="58"/>
        <source>Input MSA</source>
        <translation>Input MSA</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="58"/>
        <source>Input MSA to process.</source>
        <translation>Input MSA to process.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="59"/>
        <source>Kalign result MSA</source>
        <translation>Kalign result MSA</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="60"/>
        <source>The result of the Kalign alignment.</source>
        <translation>The result of the Kalign alignment.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="69"/>
        <source>Gap open penalty</source>
        <translation>Gap open penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="70"/>
        <source>The penalty for opening/closing a gap. Half the value will be subtracted from the alignment score when opening, and half when closing a gap.</source>
        <translation>The penalty for opening/closing a gap. Half the value will be subtracted from the alignment score when opening, and half when closing a gap.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="71"/>
        <source>Gap extension penalty</source>
        <translation>Gap extension penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="72"/>
        <source>The penalty for extending a gap.</source>
        <translation>The penalty for extending a gap.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="73"/>
        <source>Terminal gap penalty</source>
        <translation>Terminal gap penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="74"/>
        <source>The penalty to extend gaps from the N/C terminal of protein or 5&apos;/3&apos; terminal of nucleotide sequences.</source>
        <translation>The penalty to extend gaps from the N/C terminal of protein or 5&apos;/3&apos; terminal of nucleotide sequences.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="75"/>
        <source>Bonus score</source>
        <translation>Bonus score</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="76"/>
        <source>A bonus score that is added to each pair of aligned residues.</source>
        <translation>A bonus score that is added to each pair of aligned residues.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="83"/>
        <source>Align with Kalign</source>
        <translation>Align with Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="84"/>
        <source>Aligns multiple sequence alignments (MSAs) supplied with Kalign.&lt;p&gt;Kalign is a fast and accurate multiple sequence alignment tool. The original version of the tool can be found on &lt;a href=&quot;http://msa.sbc.su.se&quot;&gt;http://msa.sbc.su.se&lt;/a&gt;.</source>
        <translation>Aligns multiple sequence alignments (MSAs) supplied with Kalign.&lt;p&gt;Kalign is a fast and accurate multiple sequence alignment tool. The original version of the tool can be found on &lt;a href=&quot;http://msa.sbc.su.se&quot;&gt;http://msa.sbc.su.se&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="160"/>
        <source>An empty MSA &apos;%1&apos; has been supplied to Kalign.</source>
        <translation>An empty MSA &apos;%1&apos; has been supplied to Kalign.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="188"/>
        <source>Aligned %1 with Kalign</source>
        <translation>Aligned %1 with Kalign</translation>
    </message>
</context>
</TS>

==> ugene_1.25.0%2Bdfsg.orig.tar.xz: ugene-1.25.0/src/plugins_3rdparty/kalign/transl/english.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US" sourcelanguage="en">
<context>
    <name>KalignDialog</name>
    <message>
        <location filename="../src/KalignDialog.ui" line="32"/>
        <source>Align with Kalign</source>
        <translation>Align with Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="46"/>
        <source>Input and output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="54"/>
        <source>Input file</source>
        <translation>Input file</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="64"/>
        <location filename="../src/KalignDialog.ui" line="81"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="71"/>
        <location filename="../src/KalignDialog.ui" line="307"/>
        <source>Output file</source>
        <translation>Output file</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="99"/>
        <source>Advanced options</source>
        <translation>Advanced options</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="114"/>
        <source>Gap open penalty</source>
        <translation>Gap open penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="160"/>
        <source>Gap extension penalty</source>
        <translation>Gap extension penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="206"/>
        <source>Terminal gap penalty</source>
        <translation>Terminal gap penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="252"/>
        <source>Bonus score</source>
        <translation>Bonus score</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="295"/>
        <source>Translate to amino when aligning</source>
        <translation>Translate to amino when aligning</translation>
    </message>
</context>
<context>
    <name>PairwiseAlignmentHirschbergOptionsPanelMainWidget</name>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="37"/>
        <source>Gap open penalty</source>
        <translation>Gap open penalty</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="57"/>
        <source>Gap extension penalty</source>
        <translation>Gap extension penalty</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="77"/>
        <source>Terminate gap penalty</source>
        <translation>Terminate gap penalty</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="97"/>
        <source>Bonus score</source>
        <translation>Bonus score</translation>
    </message>
</context>
<context>
    <name>U2::KalignAdapter</name>
    <message>
        <location filename="../src/KalignAdapter.cpp" line="54"/>
        <source>Internal Kalign error: %1</source>
        <translation>Internal Kalign error: %1</translation>
    </message>
</context>
<context>
    <name>U2::KalignAlignWithExtFileSpecifyDialogController</name>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="128"/>
        <source>Align</source>
        <translation>Align</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="129"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="146"/>
        <source>Open an alignment file</source>
        <translation>Open an alignment file</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="160"/>
        <source>Save an multiple alignment file</source>
        <translation>Save an multiple alignment file</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="193"/>
        <location filename="../src/KalignDialogController.cpp" line="196"/>
        <source>Kalign with Align</source>
        <translation>Align with Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="194"/>
        <source>Input file is not set!</source>
        <translation>Input file is not set!</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="197"/>
        <source>Output file is not set!</source>
        <translation>Output file is not set!</translation>
    </message>
</context>
<context>
    <name>U2::KalignDialogController</name>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="63"/>
        <source>Align</source>
        <translation>Align</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="64"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>U2::KalignGObjectRunFromSchemaTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="255"/>
        <source>Workflow wrapper &apos;%1&apos;</source>
        <translation>Workflow wrapper &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="265"/>
        <source>KAlign align &apos;%1&apos;</source>
        <translation>KAlign align &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::KalignGObjectTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="146"/>
        <source>KALIGN align &apos;%1&apos;</source>
        <translation>KALIGN align &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::KalignMSAEditorContext</name>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="154"/>
        <source>Align with Kalign...</source>
        <translation>Align with Kalign...</translation>
    </message>
</context>
<context>
    <name>U2::KalignPlugin</name>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="70"/>
        <source>Kalign</source>
        <translation>Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="71"/>
        <source>A port of Kalign package for multiple sequence alignment. Check http://msa.sbc.su.se for the original version</source>
        <translation>A port of Kalign package for multiple sequence alignment. Check http://msa.sbc.su.se for the original version</translation>
    </message>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="81"/>
        <source>Align with Kalign...</source>
        <translation>Align with Kalign...</translation>
    </message>
</context>
<context>
    <name>U2::KalignTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="73"/>
        <source>KALIGN alignment</source>
        <translation>KALIGN alignment</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="91"/>
        <source>Unsupported alphabet: %1</source>
        <translation>Unsupported alphabet: %1</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="94"/>
        <source>Kalign alignment started</source>
        <translation>Kalign alignment started</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="99"/>
        <source>Kalign alignment successfully finished</source>
        <translation>Kalign alignment successfully finished</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::KalignPrompter</name>
    <message>
        <location filename="../src/KalignWorker.cpp" line="122"/>
        <source> from %1</source>
        <translation> from %1</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="124"/>
        <source>Aligns each MSA supplied &lt;u&gt;%1&lt;/u&gt; with &quot;&lt;u&gt;Kalign&lt;/u&gt;&quot;.</source>
        <translation>Aligns each MSA supplied &lt;u&gt;%1&lt;/u&gt; with &quot;&lt;u&gt;Kalign&lt;/u&gt;&quot;.</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::KalignWorker</name>
    <message>
        <location filename="../src/KalignWorker.cpp" line="58"/>
        <source>Input MSA</source>
        <translation>Input MSA</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="58"/>
        <source>Input MSA to process.</source>
        <translation>Input MSA to process.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="59"/>
        <source>Kalign result MSA</source>
        <translation>Kalign result MSA</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="60"/>
        <source>The result of the Kalign alignment.</source>
        <translation>The result of the Kalign alignment.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="69"/>
        <source>Gap open penalty</source>
        <translation>Gap open penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="70"/>
        <source>The penalty for opening/closing a gap. Half the value will be subtracted from the alignment score when opening, and half when closing a gap.</source>
        <translation>The penalty for opening/closing a gap. Half the value will be subtracted from the alignment score when opening, and half when closing a gap.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="71"/>
        <source>Gap extension penalty</source>
        <translation>Gap extension penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="72"/>
        <source>The penalty for extending a gap.</source>
        <translation>The penalty for extending a gap.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="73"/>
        <source>Terminal gap penalty</source>
        <translation>Terminal gap penalty</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="74"/>
        <source>The penalty to extend gaps from the N/C terminal of protein or 5&apos;/3&apos; terminal of nucleotide sequences.</source>
        <translation>The penalty to extend gaps from the N/C terminal of protein or 5&apos;/3&apos; terminal of nucleotide sequences.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="75"/>
        <source>Bonus score</source>
        <translation>Bonus score</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="76"/>
        <source>A bonus score that is added to each pair of aligned residues.</source>
        <translation>A bonus score that is added to each pair of aligned residues.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="83"/>
        <source>Align with Kalign</source>
        <translation>Align with Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="84"/>
        <source>Aligns multiple sequence alignments (MSAs) supplied with Kalign.&lt;p&gt;Kalign is a fast and accurate multiple sequence alignment tool. The original version of the tool can be found on &lt;a href=&quot;http://msa.sbc.su.se&quot;&gt;http://msa.sbc.su.se&lt;/a&gt;.</source>
        <translation>Aligns multiple sequence alignments (MSAs) supplied with Kalign.&lt;p&gt;Kalign is a fast and accurate multiple sequence alignment tool. The original version of the tool can be found on &lt;a href=&quot;http://msa.sbc.su.se&quot;&gt;http://msa.sbc.su.se&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="160"/>
        <source>An empty MSA &apos;%1&apos; has been supplied to Kalign.</source>
        <translation>An empty MSA &apos;%1&apos; has been supplied to Kalign.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="188"/>
        <source>Aligned %1 with Kalign</source>
        <translation>Aligned %1 with Kalign</translation>
    </message>
</context>
</TS>
